summaryrefslogtreecommitdiff
path: root/app/Decorator/ColumnMoveRestrictionCacheDecorator.php
diff options
context:
space:
mode:
Diffstat (limited to 'app/Decorator/ColumnMoveRestrictionCacheDecorator.php')
-rw-r--r--app/Decorator/ColumnMoveRestrictionCacheDecorator.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/app/Decorator/ColumnMoveRestrictionCacheDecorator.php b/app/Decorator/ColumnMoveRestrictionCacheDecorator.php
index cb5e860c..2a3e9c2a 100644
--- a/app/Decorator/ColumnMoveRestrictionCacheDecorator.php
+++ b/app/Decorator/ColumnMoveRestrictionCacheDecorator.php
@@ -38,17 +38,18 @@ class ColumnMoveRestrictionCacheDecorator
}
/**
* Proxy method to get column Ids
* @param int $project_id
* @return array|mixed
*/
- public function getAllSrcColumns($project_id, $role)
+ public function getSortableColumns($project_id, $role)
{
$key = $this->cachePrefix.$project_id.$role;
$columnIds = $this->cache->get($key);
if ($columnIds === null) {
- $columnIds = $this->columnMoveRestrictionModel->getAllSrcColumns($project_id, $role);
+ $columnIds = $this->columnMoveRestrictionModel->getSortableColumns($project_id, $role);
$this->cache->set($key, $columnIds);
}
@@ -38,17 +38,18 @@ class ColumnMoveRestrictionCacheDecorator
}
/**
- * Proxy method to get column Ids
+ * Proxy method to get sortable columns
+ *
* @param int $project_id
* @return array|mixed